# -*- coding: utf-8 -*-
# Django settings for bts_webui project. Settings are splitted into two files,
# this one and settings_local.py.

import os
import sys

BTS_WEBUI_ROOT = os.path.abspath(os.path.dirname(__file__))

# Specific settings for Amancay
DEFAULT_FROM_EMAIL = 'webmaster@marga.com.ar'
ACCOUNT_ACTIVATION_DAYS = 7
SESSION_SAVE_EVERY_REQUEST = True
ADMINS = (
     ('Margarita Manterola', 'marga@debian.org'),
)

EMAIL_HOST = 'localhost'
EMAIL_PORT = '1025'

MANAGERS = ADMINS

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
TIME_ZONE = 'America/Argentina/Buenos_Aires'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = True

# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
MEDIA_ROOT = ''

# URL that handles the media served from MEDIA_ROOT.
# Example: "http://media.lawrence.com"
MEDIA_URL = ''

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/media/'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
'django.template.loaders.filesystem.Loader',
'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.Loader',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.request',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
)

ROOT_URLCONF = 'bts_webui.urls'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates".
    # Always use forward slashes.
    # Don't forget to use absolute paths, not relative paths.
    "amancay/templates/",
    os.path.join(BTS_WEBUI_ROOT, 'templates'),
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.humanize',
    'django.contrib.admin',
    'django.contrib.sites',
    'registration',
    'bts_webui.amancay',
)

# Import local settings where are defined deployment dependant settings.
# SECRET_KEY must be set in local settings to avoid sharing it in VCS.
try:
    from settings_local import *
except ImportError:
    from django.utils.termcolors import colorize
    msg = ('Unable to find settings_local.py, copy settings_local.template to'
           '\nsettings_local.py and make your necessary changes.\n')
    sys.stderr.write(colorize(text=msg, fg='red', opts=('bold',)))
    sys.exit(1)
